@@ -19,6 +19,7 @@ from migration_fixer.utils import (
     get_filename,
     migration_sorter,
     no_translations,
+    sibling_nodes,
 )
 
 
@@ -46,6 +47,12 @@ class Command(BaseCommand):
             help="The name of the default branch.",
             default="main",
         )
+        parser.add_argument(
+            "-s",
+            "--skip-default-branch-update",
+            help="Skip pulling the latest changes from the default branch.",
+            action="store_true",
+        )
         parser.add_argument(
             "-r",
             "--remote",
@@ -65,6 +72,7 @@ class Command(BaseCommand):
         self.merge = options["merge"]
         self.fix = options["fix"]
         self.force_update = options["force_update"]
+        self.skip_default_branch_update = options["skip_default_branch_update"]
         self.default_branch = options["default_branch"]
         self.remote = options["remote"]
 
@@ -106,23 +114,24 @@ class Command(BaseCommand):
                             )
                         )
 
-                    if self.verbosity >= 2:
-                        self.stdout.write(
-                            f"Fetching git remote origin changes on: {self.default_branch}"
-                        )
+                    if not self.skip_default_branch_update:
+                        if self.verbosity >= 2:
+                            self.stdout.write(
+                                f"Fetching git remote {self.remote} changes on: {self.default_branch}"
+                            )
 
-                    if current_branch == self.default_branch:  # pragma: no cover
-                        remote = self.repo.remotes[self.remote]
-                        remote.pull(
-                            self.default_branch,
-                            force=self.force_update,
-                        )
-                    else:
-                        remote = self.repo.remotes[self.remote]
-                        remote.fetch(
-                            f"{self.default_branch}:{self.default_branch}",
-                            force=self.force_update,
-                        )
+                        if current_branch == self.default_branch:  # pragma: no cover
+                            remote = self.repo.remotes[self.remote]
+                            remote.pull(
+                                self.default_branch,
+                                force=self.force_update,
+                            )
+                        else:
+                            remote = self.repo.remotes[self.remote]
+                            remote.fetch(
+                                f"{self.default_branch}:{self.default_branch}",
+                                force=self.force_update,
+                            )
 
                     if self.verbosity >= 2:
                         self.stdout.write(
@@ -161,12 +170,13 @@ class Command(BaseCommand):
                         ):
                             loader.check_consistent_history(connection)
 
-                    # Before anything else, see if there's conflicting apps and drop out
-                    # hard if there are any and they don't want to merge
-                    conflicts = loader.detect_conflicts()
+                    conflicts = {
+                        app_name: sibling_nodes(loader.graph, app_name)
+                        for app_name in loader.detect_conflicts()
+                    }
 
                     for app_label in conflicts:
-                        conflict = conflicts.get(app_label)
+                        conflict = conflicts[app_label]
                         migration_module, _ = loader.migrations_module(app_label)
                         migration_absolute_path = os.path.join(
                             *migration_module.split(".")
@@ -213,8 +223,8 @@ class Command(BaseCommand):
                                     path
                                     for path in sorted_changed_files
                                     if (
-                                        int(conflict_base.split("_")[0])
-                                        >= int(get_filename(path).split("_")[0])
+                                        int(get_filename(path).split("_")[0])
+                                        >= int(conflict_base.split("_")[0])
                                     )
                                 ]
 
@@ -267,7 +277,7 @@ class Command(BaseCommand):
                                         start_name=last_remote_filename,
                                         changed_files=changed_files,
                                         writer=(
-                                            lambda message: self.stdout.write(message)
+                                            lambda m: self.stdout.write(m)
                                             if self.verbosity >= 2
                                             else lambda x: x
                                         ),
